! 
      program esope
         ! 'normal' fortran compilers do not understand esope syntax
#if 0
         segment, test 
         continue
         integer t
         endsegment
         SEGMENT, test
         continue
         integer t
         ENDSEGMENT
10         segment test1
30         continue
         endsegment
         segment
         continue
         segment = 10
         continue
         segment tra = 10
         continue
         segini,val
         segini      ,val
         segsup      ,              val
#endif
      end
